from django.db import models
from django.utils import simplejson as json
from django.conf import settings
from datetime import datetime


class JSONEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime):
            return obj.strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(obj, datetime.date):
            return obj.strftime('%Y-%m-%d')
        elif isinstance(obj, datetime.time):
            return obj.strftime('%H:%M:%S')
        return json.JSONEncoder.default(self, obj)


class JSONField(models.TextField):
    def _dumps(self, data):
        return JSONEncoder().encode(data)

    def _loads(self, str):
        return json.loads(str, encoding=settings.DEFAULT_CHARSET)

    def db_type(self):
        return 'text'

    def pre_save(self, model_instance, add):
        value = getattr(model_instance, self.attname, None)
        return self._dumps(value)

    def contribute_to_class(self, cls, name):
        self.class_name = cls
        super(JSONField, self).contribute_to_class(cls, name)
        models.signals.post_init.connect(self.post_init)

        def get_json(model_instance):
            return self._dumps(getattr(model_instance, self.attname, None))
        setattr(cls, 'get_%s_json' % self.name, get_json)

        def set_json(model_instance, json):
            return setattr(model_instance, self.attname, self._loads(json))
        setattr(cls, 'set_%s_json' % self.name, set_json)

    def post_init(self, **kwargs):
        if 'sender' in kwargs and 'instance' in kwargs:
            if kwargs['sender'] == self.class_name and hasattr(kwargs['instance'], self.attname):
                value = self.value_from_object(kwargs['instance'])
                if (value):
                    setattr(kwargs['instance'], self.attname, self._loads(value))
                else:
                    setattr(kwargs['instance'], self.attname, None)


from django.shortcuts import redirect, get_list_or_404
from django.views.generic.simple import direct_to_template
from django.template import RequestContext
from django.http import Http404, HttpResponse
from django.views.generic import date_based, list_detail
from django.db.models import Q
from django.conf import settings

from models import Page

def page_detail(request, slug):
    
    parts = request.path_info.strip("/").split("/")
    
    pages = get_list_or_404(Page, slug=parts[-1])
    
    page = None
    
    if len(pages) > 1:
        print request.path_info
        for pg in pages:
            print pg.get_absolute_url()
            if pg.get_absolute_url() == request.path_info:
                page = pg
    
    if len(pages) == 1:
        page = pages[0]
    
    if not page:
        raise Http404

    if page.status == '0':
        if not request.user.is_authenticated():
            raise Http404

    if page.redirect_to:
        return redirect(page.redirect_to)

    template_file = 'fancy/pages/%s.html' % page.template

    return direct_to_template(request, template_file, { 'page' : page })


from django.conf import settings

GALLERY_DIR = getattr(settings, 'GALLERY_DIR', "gallery")
GALLERY_ORIGINAL_IMAGESIZE = getattr(settings, 'GALLERY_ORIGINAL_IMAGESIZE', "1600x1200")
GALLERY_ENCRYPT_FILENAMES = getattr(settings, 'GALLERY_ENCRYPT_FILENAMES', False)


import django.forms as forms
from string import Template
from django.utils.safestring import mark_safe
from django.conf import settings
import os

class ImageUploaderWidget(forms.TextInput):
    def render(self, name, value, attrs=None):
        tpl = Template(u'<img src="$url" />')
        print(attrs)
        url = "%s/%s" % (settings.MEDIA_URL, value)
        return mark_safe(tpl.substitute(url=url))


from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from models import Event

def home(request):
    all_events = Event.objects.filter(status=1).order_by('-date_start')
    return render_to_response("events/list.html",{'all_events':all_events},context_instance=RequestContext(request))
    
def event_detail(request,id):
    event = get_object_or_404(Event, id=id)
    all_events = Event.objects.filter(status=1).order_by('-date_start')
    return render_to_response("events/detail.html",{'event':event, 'all_events':all_events},context_instance=RequestContext(request))



from django.contrib import admin
from models import Post, Category
from mptt.admin import MPTTModelAdmin
import admin_forms as forms
from fancy.utils.admin import BaseAdmin, MetaInline
from django.contrib.contenttypes import generic

class PostAdmin(BaseAdmin):
	prepopulated_fields = {"slug": ("title",)}
	
	list_display = ('title','date','status')
	list_filter = ['date']
	list_editable = ('date',)
	search_fields = ['title']
	date_hierarchy = 'date'
	inlines = [MetaInline]

class CategoryAdmin(MPTTModelAdmin,BaseAdmin):
	form = forms.CategoryForm
	
	list_display = ('name','slug','post_count')
	prepopulated_fields = {"slug": ("name",)}
	
admin.site.register(Post,PostAdmin)
admin.site.register(Category,CategoryAdmin)


# coding: utf-8

from django.core.management.base import BaseCommand, CommandError
from fancy.blog.models import Post, Category
from fancy.utils.models import Attribute
from django.contrib.auth.models import User
import elementtree.ElementTree as ET
from datetime import datetime

class Command(BaseCommand):
    args = 'backup_file'
    help = 'Imports posts from another blog engines (Wordpress)'

    def handle(self, *args, **options):
        try:
            xml = ET.parse( args[0] )
        except:
            raise CommandError('First argument must be valid Wordpress backup file')
        
        """
        Namespaces
        
            xmlns:excerpt="http://wordpress.org/export/1.1/excerpt/"
        	xmlns:content="http://purl.org/rss/1.0/modules/content/"
        	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
        	xmlns:dc="http://purl.org/dc/elements/1.1/"
        	xmlns:wp="http://wordpress.org/export/1.1/"
        """
        
        wpns = "{http://wordpress.org/export/1.1/}"
        
        """
        import categories
        
        <wp:category><wp:term_id>5</wp:term_id><wp:category_nicename>category-slug</wp:category_nicename><wp:category_parent></wp:category_parent><wp:cat_name><![CDATA[Category Name]]></wp:cat_name><wp:category_description><![CDATA[Category Description]]></wp:category_description></wp:category>
        """

        category_count = 0
        
        for category in xml.findall("channel/%scategory" % wpns):
            cat_slug = category.find("%scategory_nicename" % wpns).text
            
            # check is already exist
            if Category.objects.filter(slug=cat_slug).exists():
                continue

            cat_name = category.find("%scat_name" % wpns).text

            try:
                cat_desc = category.find("%scategory_description" % wpns).text
            except:
                cat_desc = ''
            
            cat_parent = category.find("%scategory_parent" % wpns).text

            # get or create imported user for category owner
            import_user, created = User.objects.get_or_create(username='imported')
        
            newCat = Category(name=cat_name, slug=cat_slug, description=cat_desc, created_by=import_user, last_updated_by=import_user)

            if cat_parent:
                try:
                    newCat.parent = Category.objects.get(slug=cat_parent)
                except:
                    pass
            
            newCat.save()
            
            self.stdout.write("Category named '%s' added.\n" % cat_name)
            
            category_count += 1
        
        self.stdout.write('%s categories succesfully imported.\n' % category_count)
        
        """
        import posts
        
        <item>
        		<title>Post title</title> 
        		# <link>http://example.com/2012/12/12/post-title/</link>
        		<pubDate>Mon, 12 Dec 2012 01:40:38 +0000</pubDate>
        		<dc:creator>admin</dc:creator>
        		# <guid isPermaLink="false">http://example.com/?p=5550</guid>
        		# <description></description>
        		<content:encoded><![CDATA[ Post Content ]]></content:encoded>
        		# <excerpt:encoded><![CDATA[]]></excerpt:encoded>
        		# <wp:post_id>5550</wp:post_id>
        		<wp:post_date>2012-12-12 04:40:38</wp:post_date>
        		<wp:post_date_gmt>2012-12-12 01:40:38</wp:post_date_gmt>
        		<wp:comment_status>open</wp:comment_status>
        		# <wp:ping_status>open</wp:ping_status>
        		<wp:post_name>post-title</wp:post_name>
        		<wp:status>publish</wp:status>
        		# <wp:post_parent>0</wp:post_parent>
        		# <wp:menu_order>0</wp:menu_order>
        		# <wp:post_type>post</wp:post_type>
        		# <wp:post_password></wp:post_password>
        		# <wp:is_sticky>0</wp:is_sticky>
        		<category domain="category" nicename="category-slug"><![CDATA[Category Name]]></category>
        		<category domain="post_tag" nicename="tag-slug"><![CDATA[Tag Name]]></category>
        		<wp:postmeta>
        			<wp:meta_key>key</wp:meta_key>
        			<wp:meta_value><![CDATA[Valye]]></wp:meta_value>
        		</wp:postmeta>
        	</item>
        """
        Post.objects.all().delete()
        
        post_count = 0
        
        for post in xml.findall("channel/item"):
            if post.find("%spost_type" % wpns).text == 'post':
                author_name = post.find("{http://purl.org/dc/elements/1.1/}creator").text
                author, created = User.objects.get_or_create(username=author_name)

                newPost = Post(author=author, created_by=author, last_updated_by=author)

                title = post.find("title").text
                
                newPost.title = 'Untitled post'
                
                if title:
                    newPost.title = title
                else:
                    if newPost.status == 1:
                        self.stderr.write("No TITLE found for post '%s'.\n" % newPost.title )

                newPost.status = 1 if post.find("%sstatus" % wpns).text == 'publish' else 0
                newPost.slug = ''
                
                slug = post.find("%spost_name" % wpns).text
                
                if slug:
                    newPost.slug = slug
                else:
                    if newPost.status == 1:
                        self.stderr.write("No SLUG data found for post '%s'.\n" % newPost.title )
                
                newPost.content = ''
                
                content = post.find("{http://purl.org/rss/1.0/modules/content/}encoded").text
                
                if content:
                    newPost.content = content
                else:
                    if newPost.status == 1:
                        self.stderr.write("No CONTENT data found for post '%s'.\n" % newPost.title )
                
                newPost.enable_comments = True if post.find("%scomment_status" % wpns).text == 'open' else False
                newPost.date = datetime.strptime( post.find("%spost_date" % wpns).text, "%Y-%m-%d %H:%M:%S")
                
                # Save to get an id
                newPost.save()
                
                for taxonomy in post.findall("category"):
                    # categories
                    if taxonomy.get("domain") == 'category':
                        postCat = Category.objects.get(slug=taxonomy.get("nicename"))
                        newPost.categories.add(postCat)
                    
                    #tags
                    if taxonomy.get("domain") == 'post_tag':
                        newPost.tags.add( taxonomy.text )
                
                newPost.save()

                # meta data
                for meta in post.findall("%spostmeta" % wpns):
                    key = meta.find("%smeta_key" % wpns).text
                    if not key: continue
                    value = meta.find("%smeta_value" % wpns).text
                    if not value: value = ''
                    
                    pm = Attribute(content_object=newPost, key=key, value=value, created_by=newPost.author, last_updated_by=newPost.author)
                    pm.save()
                    
                
                post_count += 1
                
                self.stdout.write("Title: %s \n" % newPost.title )
                    
        self.stdout.write('%s posts succesfully imported.\n' % post_count)


from django.shortcuts import get_object_or_404
from django.views.generic.simple import direct_to_template
from django.http import Http404
from models import Product, Category

def main(request):
    categories = Category.objects.all()
    return direct_to_template(request, 'fancy/products/main.html', {'categories':categories})

def category_main(request, category_slug=None, category_id=None):
    if category_id:
        category = get_object_or_404(Category, pk=category_id)
    elif category_slug:
        category = get_object_or_404(Category, slug=category_slug)
    else:
        raise Http404

    return direct_to_template(request, 'fancy/products/category_main.html', {'category':category})

def detail(request, product_slug=None, product_id=None, category_slug=None):
    if product_id:
        product = get_object_or_404(Product, pk=product_id)
    elif product_slug:
        if category_slug:
            product = get_object_or_404(Product, slug=product_slug, category__slug=category_slug)
        else:
            product = get_object_or_404(Product, slug=product_slug)
    else:
        raise Http404

    if category_slug and not product.category.slug == category_slug:
        raise Http404

    return direct_to_template(request, 'fancy/products/detail.html', {'product':product})

def main_controller(request, slug):
    parts = request.path_info.strip("/").split("/")
    
    print parts, parts[-1]
    # Check products
    if Product.objects.filter(slug=parts[-1], category__slug=parts[-2]).exists():
        return detail(request, product_slug=parts[-1], category_slug=parts[-2])

    return category_main(request, parts[-1])


from django.contrib.syndication.views import Feed
from models import Post
import markdown
import settings

class LatestEntriesFeed(Feed):
    title = settings.FEED_TITLE
    link = settings.FEED_LINK
    description = settings.FEED_DESCRIPTION

    def items(self):
        return Post.objects.order_by('-date')[:10]

    def item_title(self, item):
        return item.title

    def item_description(self, item):
        return markdown.markdown(item.content)


from django import forms
from django.utils.translation import ugettext_lazy as _

from mptt.forms import TreeNodeChoiceField

from models import Category, Product

class CategoryForm(forms.ModelForm):

    parent = TreeNodeChoiceField(   queryset=Category.tree.all(),
                                    level_indicator=3*unichr(160),
                                    empty_label='---------',
                                    required=False)

    class Meta:
        model = Category

class ProductForm(forms.ModelForm):

    category = TreeNodeChoiceField( queryset=Category.tree.all(),
                                    level_indicator=3*unichr(160),
                                    empty_label='---------',
                                    required=True)

    class Meta:
        model = Product



from django.contrib import admin
from django.conf import settings
from models import Album, Image
from django.utils.translation import ugettext_lazy as _
from fancy.utils.admin import BaseAdmin
from django.contrib.contenttypes import generic

class ImageInline(generic.GenericTabularInline):
    model = Image
    extra = 1
    prepopulated_fields = {"slug": ("name",)}

class AlbumAdmin(BaseAdmin):
    prepopulated_fields = {"slug": ("name",)}
    list_display = ('id','name')
    ordering = ('id',)

    inlines = [ImageInline,]

admin.site.register(Album,AlbumAdmin)



from django.template import TemplateSyntaxError
from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.http import Http404
from django.utils.encoding import smart_unicode
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
from models import Album

def inlines(value, return_list=False):
    try:
        from BeautifulSoup import BeautifulStoneSoup, BeautifulSoup
    except ImportError:
        from beautifulsoup import BeautifulStoneSoup, BeautifulSoup
    
    content = BeautifulSoup(value, selfClosingTags=['gallery','img','br','input','meta','link','hr'])
    inline_list = []

    if return_list:
        for inline in content.findAll('gallery'):
            rendered_inline = render_inline(inline)
            inline_list.append(rendered_inline['context'])
        return inline_list
    else:
        for inline in content.findAll('gallery'):
            rendered_inline = render_inline(inline)
            if rendered_inline:
                inline.replaceWith(render_to_string(rendered_inline['template'], rendered_inline['context']))
            else:
                inline.replaceWith('')
        return mark_safe(content)


def render_inline(inline):
    """
    Replace inline markup with template markup that matches the
    appropriate app and model.

    """

    # Look for inline type, 'app.model'
    try:
        id = inline['id']
    except:
        if settings.DEBUG:
            raise TemplateSyntaxError, "Couldn't find the attribute 'id' in the <gallery> tag."
        else:
            return ''

    album = Album.objects.get(pk=id)
    context = { 'album': album, }

    template = ["fancy/gallery/inline_album.html"]
    rendered_inline = {'template':template, 'context':context}

    return rendered_inline


from django.db import models
from django import forms
from django.conf import settings
import settings as pages_settings
from django.utils.translation import ugettext_lazy as _
from fancy.utils import slugify
from fancy.utils.models import MetadataModel, BaseModel
from mptt.models import MPTTModel

class Page(MPTTModel,BaseModel,MetadataModel):
    language = models.CharField(_('Language'), max_length=5, choices=settings.LANGUAGES, default=settings.LANGUAGE_CODE)
    title = models.CharField(_('Title'), max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    template = models.CharField(_('Page template'), max_length=50, choices=pages_settings.PAGE_TEMPLATES, default='default')
    order_number = models.PositiveSmallIntegerField(_('Order Number'),help_text=_('Page Order Number'),default=0)
    content = models.TextField(_('Page Content'),blank=True)
    show_in_menu = models.BooleanField(_('Show in Menu'), default=False)
    redirect_to = models.CharField(_('Redirect to'),help_text=_("Redirect this url to another url instead of showing"),blank=True,null=True,max_length=100)
    
    STATUSES = (
        ('0', _('Draft')),
        ('1', _('Active')),
    )
    status = models.CharField(_('Status'), max_length=1, choices=STATUSES, default='1')
    parent = models.ForeignKey('self', verbose_name=_(u'parent'), blank=True, null=True, related_name='children')
    
    class Meta(BaseModel.Meta):
        verbose_name = _('Page')
        verbose_name_plural = _('Pages')

    class MPTTMeta:
        order_insertion_by = ['order_number']

    def __unicode__(self):
        return self.title

    def save(self, *args, **kwargs):
        if self.slug == '':
            self.slug = slugify(self.title)

        super(Page, self).save(*args, **kwargs) # Call the "real" save() method.

    def get_active_child_menus(self):
        return self.children.defer('content').filter(status=1,show_in_menu=True)
    
    def get_active_children(self):
        return self.children.filter(status=1).order_by('order_number','title')

    def render(self):
        if pages_settings.PAGE_DEFAULT_CONTENT_TYPE == 'md':
            from django.contrib.markup.templatetags.markup import markdown
            return markdown(self.content,'nl2br,markdown-urlize')

        return self.content

    @models.permalink
    def get_absolute_url(self):
        if not getattr(self, '_slug', None):
            url = self.slug
            for ancestor in self.get_ancestors(True):
                url = ancestor.slug + u'/' + url
            self._slug = url    
        return ('pages_page_detail', (), {'slug' : str(self._slug) } )



import uuid, os
from settings import GALLERY_ENCRYPT_FILENAMES, GALLERY_DIR
from datetime import datetime
from fancy.utils import slugify
import hashlib

def get_upload_path(instance, filename):
    parts = filename.split('.')
    ext = parts[-1]
    parts.pop()
    basename = '.'.join(parts)

    today = datetime.now()
    
    if GALLERY_ENCRYPT_FILENAMES:
        time_string = today.strftime("%H-%M-%S")
        hash = hashlib.sha224( "%s-%s" % (filename, time_string) ).hexdigest()
        path = os.path.join(GALLERY_DIR, "%s/%s/%s.%s" % (hash[:2], hash[2:4], hash, ext.lower()) )
    else:
        date_path = today.strftime("%Y/%m")
        
        path = os.path.join(GALLERY_DIR, date_path, "%s.%s" % (slugify(basename), ext.lower()))
        
    return path



from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from fancy.utils.models import BaseModel

class Location(BaseModel):
    name = models.CharField(_("Location Name"), max_length=150)
    lat = models.FloatField(_("Location Latitude"))
    lon = models.FloatField(_("Location Longitude"))
    
    class Meta:
        verbose_name = _('Location')
        verbose_name_plural = _('Locations')
        ordering = ('name',)

    def __unicode__(self):
        return self.name

EVENT_STATUSES = (
	(0, _('Unpublished')),
	(1, _('Public')),
	(2, _('Private')),
)

class Event(BaseModel):
    name = models.CharField(_("Event Name"), max_length=250)
    date_start = models.DateTimeField(_("Event Start Date"))
    date_end = models.DateTimeField(_("Event End Date"))
    location = models.ForeignKey(Location,verbose_name=_('Location'))
    description = models.TextField(_('Event Description'),blank=True)
    status = models.IntegerField(_('Status'),default=0,choices=EVENT_STATUSES)
    owner = models.ForeignKey(User, verbose_name=_('Owner'),editable=False)
    
    class Meta:
        verbose_name = _('Event')
        verbose_name_plural = _('Events')
        ordering = ('-date_start',)

    def __unicode__(self):
        return self.name


# coding: utf-8

from django.core.management.base import BaseCommand, CommandError
from fancy.pages.models import Page
from fancy.utils.models import Attribute
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth.models import User

import elementtree.ElementTree as ET
from datetime import datetime

class Command(BaseCommand):
    args = 'backup_file'
    help = 'Imports pages from another blog engines (Wordpress)'

    def handle(self, *args, **options):
        try:
            xml = ET.parse( args[0] )
        except:
            raise CommandError('First argument must be valid Wordpress backup file')
        
        """
        Namespaces
        
            xmlns:excerpt="http://wordpress.org/export/1.1/excerpt/"
        	xmlns:content="http://purl.org/rss/1.0/modules/content/"
        	xmlns:wfw="http://wellformedweb.org/CommentAPI/"
        	xmlns:dc="http://purl.org/dc/elements/1.1/"
        	xmlns:wp="http://wordpress.org/export/1.1/"
        """
        
        wpns = "{http://wordpress.org/export/1.1/}"
        
        """
        import pages
        
        <item>
        		<title>Çorum Gazetesi</title>
        		<link>http://ahmetturanalkan.net/?page_id=2658</link>
        		<pubDate>Thu, 01 Jan 1970 00:00:00 +0000</pubDate>
        		<dc:creator>admin</dc:creator>
        		<guid isPermaLink="false">http://ahmetturanalkan.net//</guid>
        		<description></description>
        		<content:encoded><![CDATA[Page content]]></content:encoded>
        		<excerpt:encoded><![CDATA[]]></excerpt:encoded>
        		<wp:post_id>2658</wp:post_id>
        		<wp:post_date>2007-03-20 22:27:30</wp:post_date>
        		<wp:post_date_gmt>0000-00-00 00:00:00</wp:post_date_gmt>
        		<wp:comment_status>open</wp:comment_status>
        		<wp:ping_status>open</wp:ping_status>
        		<wp:post_name></wp:post_name>
        		<wp:status>draft</wp:status>
        		<wp:post_parent>2582</wp:post_parent>
        		<wp:menu_order>0</wp:menu_order>
        		<wp:post_type>page</wp:post_type>
        		<wp:post_password></wp:post_password>
        		<wp:is_sticky>0</wp:is_sticky>
        		<wp:postmeta>
        			<wp:meta_key>_wp_page_template</wp:meta_key>
        			<wp:meta_value><![CDATA[default]]></wp:meta_value>
        		</wp:postmeta>
        	</item>
       
            language = models.CharField(_('Language'), max_length=5, choices=settings.LANGUAGES, default=settings.LANGUAGE_CODE)
            title = models.CharField(_('Title'), max_length=200)
            slug = models.SlugField(_('Slug'), max_length=200, blank=True)
            template = models.CharField(_('Page template'), max_length=50, choices=pages_settings.PAGE_TEMPLATES, default='default')
            order_number = models.PositiveSmallIntegerField(_('Order Number'),help_text=_('Page Order Number'),default=0)
            content = tinymce_models.HTMLField(_('Page Content'),blank=True)
            show_in_menu = models.BooleanField(_('Show in Menu'), default=False)
            redirect_to = models.CharField(_('Redirect to'),help_text=_("Redirect this url to another url instead of showing"),blank=True,null=True,max_length=100)
            created_date = models.DateTimeField(_('Publish Date'), default=datetime.now())
            last_modified = models.DateTimeField(_('Last Modified Date'), default=datetime.now())

            STATUSES = (
                ('0', _('Draft')),
                ('1', _('Active')),
            )
            status = models.CharField(_('Status'), max_length=1, choices=STATUSES, default='1')
            parent = models.ForeignKey('self', verbose_name=_(u'parent'), blank=True, null=True, related_name='children') 
        """
        Page.objects.all().delete()
        
        Wordpress_ID_conversions = {}
        parents = {}
        
        post_count = 0
        
        for post in xml.findall("channel/item"):
            if post.find("%spost_type" % wpns).text == 'page':
                author_name = post.find("{http://purl.org/dc/elements/1.1/}creator").text
                author, created = User.objects.get_or_create(username=author_name)

                newPost = Page(created_by=author, last_updated_by=author)

                title = post.find("title").text
                
                newPost.title = 'Untitled page'
                
                if title:
                    newPost.title = title
                else:
                    if newPost.status == 1:
                        self.stderr.write("No TITLE found for post '%s'.\n" % newPost.title )

                newPost.status = 1 if post.find("%sstatus" % wpns).text == 'publish' else 0
                newPost.slug = ''
                
                slug = post.find("%spost_name" % wpns).text
                
                if slug:
                    newPost.slug = slug
                else:
                    if newPost.status == 1:
                        self.stderr.write("No SLUG data found for post '%s'.\n" % newPost.title )
                
                newPost.content = ''
                
                content = post.find("{http://purl.org/rss/1.0/modules/content/}encoded").text
                
                if content:
                    newPost.content = content
                else:
                    if newPost.status == 1:
                        self.stderr.write("No CONTENT data found for post '%s'.\n" % newPost.title )
                
                newPost.show_in_menu = True
                newPost.order_number = int(post.find("%spost_parent" % wpns).text)
                try:
                    newPost.created_date = datetime.strptime( post.find("%spost_date" % wpns).text, "%Y-%m-%d %H:%M:%S")
                    newPost.last_modified = datetime.strptime( post.find("%spost_date" % wpns).text, "%Y-%m-%d %H:%M:%S")
                except:
                    pass
                
                # Save to get an id
                newPost.save()
                
                post_id = post.find("%spost_id" % wpns).text
                Wordpress_ID_conversions[post_id] = newPost.id
                
                parent_id = post.find("%spost_parent" % wpns).text
                
                if parent_id:
                    parents[post_id] = parent_id
                
                # meta data
                """ page_type = ContentType.objects.get_for_model(Page)
                
                for meta in post.findall("%spostmeta" % wpns):
                    
                    key = meta.find("%smeta_key" % wpns).text
                    if not key: continue
                    value = meta.find("%smeta_value" % wpns).text
                    if not value: value = ''
                    
                    pm = Attribute(content_type=page_type, object_id=newPost.id, key=key, value=value)
                    pm.save()
                    
                """
                
                post_count += 1
                
                self.stdout.write("Title: %s \n" % newPost.title )
        
        self.stdout.write("Writing parent-child relations... \n")
        
        for post_id, parent_id in parents.iteritems():
            if int(parent_id) > 0:
                real_post = Page.objects.get(pk=Wordpress_ID_conversions[post_id])
                real_post.parent = Page.objects.get(pk=Wordpress_ID_conversions[parent_id])
                real_post.save()
        
        self.stdout.write("Relations wrote.\n")
        
        self.stdout.write('%s pages succesfully imported.\n' % post_count)


from fancy.events.models import Event, Location
from django.contrib import admin
from fancy.utils.admin import BaseAdmin

class EventAdmin(BaseAdmin):
    fields = ('name','date_start','date_end','location','description','status')
    list_display = ('name', 'owner', 'date_start')
    search_fields = ['name']
    date_hierarchy = 'date_start'

    def save_model(self, request, obj, form, change): 
        instance = form.save(commit=False)
        instance.owner = request.user
        instance.save()
        return instance

admin.site.register(Event, EventAdmin)
admin.site.register(Location, BaseAdmin)



from django.conf.urls.defaults import *
from sitemap import PageSitemap

sitemaps = {
    'pages' : PageSitemap,
}

urlpatterns = patterns('',
    url(r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap', {'sitemaps': sitemaps } ),
    url(r'^(?P<slug>[-\w\/]+)/$',
        view='fancy.pages.views.page_detail',
        name='pages_page_detail'
    ),
    
)




from django import template
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
register = template.Library()

"""
Usage: 

{% load mailform %} <!-- Loads mailform templatetag library -->

{% show_mailform %} <!-- Shows default.html form -->

{% show_mailform "contact_form.html" %} <!-- Shows contact_form.html form -->

TODO: csrf protection should work
"""
@register.simple_tag()
def show_mailform(template="default.html"):
    return render_to_string("fancy/mailform/%s" % template, {} )

"""
Usage:

page.content has mailform tag like that: <mailform template="contact_form.html" />

{{ page.content|render_mailform }}
"""
@register.filter
def render_mailform(value):
    try:
        from BeautifulSoup import BeautifulSoup
    except ImportError:
        from beautifulsoup import BeautifulSoup
    
    content = BeautifulSoup(value, selfClosingTags=['mailform','img','br','input','meta','link','hr'])

    for inline in content.findAll('mailform'):
        try:
            tpl = inline["template"]
        except:
            tpl = "default.html"
        
        inline.replaceWith(show_mailform(tpl))

    return mark_safe(content)